==> php54-owncloud-7.0.4.tgz: share/owncloud/apps/calendar/l10n/lv.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Ne visi kalendāri ir pilnībā pieglabāti",
"Everything seems to be completely cached" => "Izskatās, ka viss ir pilnībā pieglabāts",
"No calendars found." => "Nav atrastu kalendāru.",
"No events found." => "Nav atrastu notikumu.",
"Wrong calendar" => "Nepareizs kalendārs",
"You do not have the permissions to edit this event." => "Jums nav tiesību rediģēt šo notikumu.",
"The file contained either no events or all events are already saved in your calendar." => "Datne nesaturēja nevienu notikumu, vai arī visi notikumi jau ir saglabāti jūsu kalendārā,",
"Import failed" => "neizdevās importēt",
"New Timezone:" => "Jauna laika josla",
"Timezone changed" => "Laika josla ir nomainīta",
"Invalid request" => "Nederīgs vaicājums",
"Calendar" => "Kalendārs",
"Deletion failed" => "Neizdevās izdzēst",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"group" => "grupa",
"can edit" => "var rediģēt",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Svētdiena",
"Monday" => "Pirmdiena",
"Tuesday" => "Otrdiena",
"Wednesday" => "Trešdiena",
"Thursday" => "Ceturtdiena",
"Friday" => "Piektdiena",
"Saturday" => "Sestdiena",
"Sun." => "Sv.",
"Mon." => "Pr.",
"Tue." => "Ot.",
"Wed." => "Tr.",
"Thu." => "Ce.",
"Fri." => "Pk.",
"Sat." => "Se.",
"January" => "Janvāris",
"February" => "Februāris",
"March" => "Marts",
"April" => "Aprīlis",
"May" => "Maijs",
"June" => "Jūnijs",
"July" => "Jūlijs",
"August" => "Augusts",
"September" => "Septembris",
"October" => "Oktobris",
"November" => "Novembris",
"December" => "Decembris",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Mai.",
"Jun." => "Jūn.",
"Jul." => "Jūl.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "Visu dienu",
"New Calendar" => "Jauns kalendārs",
"Missing or invalid fields" => "Trūkstoši vai nederīgi lauki",
"Title" => "Nosaukums",
"From Date" => "Sākuma datums",
"From Time" => "Sākuma laiks",
"To Date" => "Beigu datums",
"To Time" => "Beigu laiks",
"The event ends before it starts" => "Notikums beidzas vēl nesācies",
"There was a database fail" => "Datubāzes kļūme",
"Birthday" => "Dzimšanas diena",
"Business" => "Darījumi",
"Call" => "Zvans",
"Clients" => "Klienti",
"Deliverer" => "Piegādātājs",
"Holidays" => "Brīvdienas",
"Ideas" => "Idejas",
"Journey" => "Ceļojums",
"Jubilee" => "Jubileja",
"Meeting" => "Tikšanās",
"Other" => "Cits",
"Personal" => "Personīgi",
"Projects" => "Projekti",
"Questions" => "Jautājumi",
"Work" => "Darbs",
"by" => "līdz",
"unnamed" => "nenosaukts",
"You do not have the permissions to update this calendar." => "Jums nav tiesību atjaunināt šo kalendāru.",
"You do not have the permissions to delete this calendar." => "Jums nav tiesību dzēst šo kalendāru.",
"You do not have the permissions to add to this calendar." => "Jums nav tiesību pievienot šim kalendāram.",
"You do not have the permissions to add events to this calendar." => "Jums nav tiesību pievienot notikumus šim kalendāram.",
"You do not have the permissions to delete this event." => "Jums nav tiesību dzēst šo notikumu.",
"Busy" => "Aizņemts",
"Does not repeat" => "Neatkārtojas",
"Daily" => "Katru dienu",
"Weekly" => "Katru nedēļu",
"Every Weekday" => "Katrā nedēļas dienā",
"Bi-Weekly" => "Katru otro nedēļu",
"Monthly" => "Katru mēnesi",
"Yearly" => "Katru gadu",
"never" => "nekad",
"by occurrences" => "pēc reižu skaita",
"by date" => "līdz datumam",
"by monthday" => "pēc mēneša dienas",
"by weekday" => "pēc nedēļas dienas",
"events week of month" => "notikuma mēneša nedēļa",
"first" => "pirmais",
"second" => "otrais",
"third" => "trešais",
"fourth" => "ceturtais",
"fifth" => "piektais",
"last" => "pēdējais",
"by events date" => "pēc notikumu datuma",
"by yearday(s)" => "pēc gada dienas(-ām)",
"by weeknumber(s)" => "pēc nedēļas numura(-iem)",
"by day and month" => "pēc dienas un mēneša",
"Date" => "Datums",
"Cal." => "Kal.",
"Week" => "Nedēļa",
"Month" => "Mēnesis",
"Today" => "Šodien",
"CalDav Link" => "CalDav saite",
"Timezone" => "Laika josla",
"Update timezone automatically" => "Automātiski atjaunināt laika joslas",
"Time format" => "Laika formāts",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Sākt nedēļu ar",
"Cache" => "Kešatmiņa",
"Clear cache for repeating events" => "Attīrīt kešatmiņu no notikumiem, kas atkārtojas",
"Share Calendar" => "Dalīties ar kalendāru",
"Download" => "Lejupielādēt",
"Edit" => "Rediģēt",
"Delete" => "Dzēst",
"New calendar" => "Jauns kalendārs",
"Edit calendar" => "Rediģēt kalendāru",
"Eventinfo" => "Notikuma info",
"Repeating" => "Atkārtojas",
"Alarm" => "Signāls",
"Attendees" => "Apmeklētāji",
"Share" => "Dalīties",
"Title of the Event" => "Notikuma nosaukums",
"All Day Event" => "Visas dienas notikums",
"Advanced options" => "Paplašinātās opcijas",
"Location" => "Vieta",
"Edit categories" => "Rediģēt kategoriju",
"Description" => "Apraksts",
"Repeat" => "Atkārtot",
"Advanced" => "Paplašināti",
"Select weekdays" => "Izvēlieties nedēļas dienas",
"Select days" => "Izvēlieties dienas",
"and the events day of year." => "un notikuma gada dienu.",
"and the events day of month." => "un notikuma mēneša dienu.",
"Select months" => "Izvēlieties mēnešus",
"Select weeks" => "Izvēlieties nedēļas",
"and the events week of year." => "un notikuma gada nedēļu.",
"Interval" => "Intervāls",
"End" => "Beigas",
"occurrences" => "notikumu skaits",
"create a new calendar" => "izveidot jaunu kalendāru",
"Import a calendar file" => "Importēt kalendāra datni",
"Please choose a calendar" => "Lūdzu, izvēlieties kalendāru",
"Name of new calendar" => "Jaunā kalendāra nosaukums",
"Take an available name!" => "Paņemiet pieejamu nosaukumu!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendārs ar tādu nosaukumu jau eksistē. Ja tomēr turpināsiet, šie kalendāri tiks apvienoti.",
"Remove all events from the selected calendar" => "Izņemt visus notikumus no izvēlētā kalendāra",
"Import" => "Importēt",
"Close Dialog" => "Aizvērt dialoglodziņu",
"Create a new event" => "Izveidot jaunu notikumu",
"Unshare" => "Pārtraukt dalīšanos",
"Shared via calendar" => "Koplietots caur kalendāru",
"View an event" => "Skatīt notikumu",
"Category" => "Kategorija",
"No categories selected" => "Nav izvēlētu kategoriju",
"Access Class" => "Pieejas klase",
"From" => "No",
"at" => " ",
"To" => "Līdz"
);

==> php54-owncloud-8.0.0.tgz: share/owncloud/apps/calendar/l10n/lv.php <==
<?php
$TRANSLATIONS = array(
"Not all calendars are completely cached" => "Ne visi kalendāri ir pilnībā pieglabāti",
"Everything seems to be completely cached" => "Izskatās, ka viss ir pilnībā pieglabāts",
"No calendars found." => "Nav atrastu kalendāru.",
"No events found." => "Nav atrastu notikumu.",
"Wrong calendar" => "Nepareizs kalendārs",
"You do not have the permissions to edit this event." => "Jums nav tiesību rediģēt šo notikumu.",
"The file contained either no events or all events are already saved in your calendar." => "Datne nesaturēja nevienu notikumu, vai arī visi notikumi jau ir saglabāti jūsu kalendārā,",
"events have been saved in the new calendar" => "notikumi tika saglabāti jaunajā kalendārā",
"Import failed" => "neizdevās importēt",
"events have been saved in your calendar" => "notikumi tika saglabāti jūsu kalendārā",
"New Timezone:" => "Jauna laika josla",
"Timezone changed" => "Laika josla ir nomainīta",
"Invalid request" => "Nederīgs vaicājums",
"Calendar" => "Kalendārs",
"Error sending mail" => "Kļūda nosūtot epastu",
"Deletion failed" => "Neizdevās izdzēst",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}",
"Do you really want to delete this calendar?" => "Tai tiešām vēlaties dzēst šo kalendāru?",
"group" => "grupa",
"can edit" => "var rediģēt",
"can share" => "Var dalīties",
"ddd" => "ddd",
"ddd M/d" => "ddd M/d",
"dddd M/d" => "dddd M/d",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "MMM d[ yyyy]{ '–'[ MMM] d yyyy}",
"dddd, MMM d, yyyy" => "dddd, MMM d, yyyy",
"Sunday" => "Svētdiena",
"Monday" => "Pirmdiena",
"Tuesday" => "Otrdiena",
"Wednesday" => "Trešdiena",
"Thursday" => "Ceturtdiena",
"Friday" => "Piektdiena",
"Saturday" => "Sestdiena",
"Sun." => "Sv.",
"Mon." => "Pr.",
"Tue." => "Ot.",
"Wed." => "Tr.",
"Thu." => "Ce.",
"Fri." => "Pk.",
"Sat." => "Se.",
"January" => "Janvāris",
"February" => "Februāris",
"March" => "Marts",
"April" => "Aprīlis",
"May" => "Maijs",
"June" => "Jūnijs",
"July" => "Jūlijs",
"August" => "Augusts",
"September" => "Septembris",
"October" => "Oktobris",
"November" => "Novembris",
"December" => "Decembris",
"Jan." => "Jan.",
"Feb." => "Feb.",
"Mar." => "Mar.",
"Apr." => "Apr.",
"May." => "Mai.",
"Jun." => "Jūn.",
"Jul." => "Jūl.",
"Aug." => "Aug.",
"Sep." => "Sep.",
"Oct." => "Okt.",
"Nov." => "Nov.",
"Dec." => "Dec.",
"All day" => "Visu dienu",
"New Calendar" => "Jauns kalendārs",
"Missing or invalid fields" => "Trūkstoši vai nederīgi lauki",
"Title" => "Nosaukums",
"From Date" => "Sākuma datums",
"From Time" => "Sākuma laiks",
"To Date" => "Beigu datums",
"To Time" => "Beigu laiks",
"The event ends before it starts" => "Notikums beidzas vēl nesācies",
"There was a database fail" => "Datubāzes kļūme",
"Interval is not valid. It must be a positive integer!" => "Nederīgs intervāls. Tam jābūt pozitīvam skaitlim!",
"Birthday" => "Dzimšanas diena",
"Business" => "Darījumi",
"Call" => "Zvans",
"Clients" => "Klienti",
"Deliverer" => "Piegādātājs",
"Holidays" => "Brīvdienas",
"Ideas" => "Idejas",
"Journey" => "Ceļojums",
"Jubilee" => "Jubileja",
"Meeting" => "Tikšanās",
"Other" => "Cits",
"Personal" => "Personīgi",
"Projects" => "Projekti",
"Questions" => "Jautājumi",
"Work" => "Darbs",
"by" => "līdz",
"unnamed" => "nenosaukts",
"You do not have the permissions to update this calendar." => "Jums nav tiesību atjaunināt šo kalendāru.",
"You do not have the permissions to delete this calendar." => "Jums nav tiesību dzēst šo kalendāru.",
"You do not have the permissions to add to this calendar." => "Jums nav tiesību pievienot šim kalendāram.",
"You do not have the permissions to add events to this calendar." => "Jums nav tiesību pievienot notikumus šim kalendāram.",
"You cannot add non-public events to a shared calendar." => "Jūs nevarat pievienot privātus notikumus koplietotam kalendāram.",
"You do not have the permissions to delete this event." => "Jums nav tiesību dzēst šo notikumu.",
"Busy" => "Aizņemts",
"Show full event" => "Rādīt pilnu notikumu",
"Show only busy" => "Rādīt tikai aizņemto",
"Hide event" => "Slēpt notikumu",
"Does not repeat" => "Neatkārtojas",
"Daily" => "Katru dienu",
"Weekly" => "Katru nedēļu",
"Every Weekday" => "Katrā nedēļas dienā",
"Bi-Weekly" => "Katru otro nedēļu",
"Monthly" => "Katru mēnesi",
"Yearly" => "Katru gadu",
"never" => "nekad",
"by occurrences" => "pēc reižu skaita",
"by date" => "līdz datumam",
"by monthday" => "pēc mēneša dienas",
"by weekday" => "pēc nedēļas dienas",
"events week of month" => "notikuma mēneša nedēļa",
"first" => "pirmais",
"second" => "otrais",
"third" => "trešais",
"fourth" => "ceturtais",
"fifth" => "piektais",
"last" => "pēdējais",
"by events date" => "pēc notikumu datuma",
"by yearday(s)" => "pēc gada dienas(-ām)",
"by weeknumber(s)" => "pēc nedēļas numura(-iem)",
"by day and month" => "pēc dienas un mēneša",
"Contact birthdays" => "Kontaktu jubilejas",
"Date" => "Datums",
"Day" => "Diena",
"Week" => "Nedēļa",
"Month" => "Mēnesis",
"Today" => "Šodien",
"CalDav Link" => "CalDav saite",
"Timezone" => "Laika josla",
"Update timezone automatically" => "Automātiski atjaunināt laika joslas",
"Time format" => "Laika formāts",
"24h" => "24h",
"12h" => "12h",
"Start week on" => "Sākt nedēļu ar",
"Cache" => "Kešatmiņa",
"Clear cache for repeating events" => "Attīrīt kešatmiņu no notikumiem, kas atkārtojas",
"Primary CalDAV address" => "Primārā CalDAV adrese",
"iOS/OS X CalDAV address" => "iOS/OS X CalDAV adrese",
"Share Calendar" => "Dalīties ar kalendāru",
"Download" => "Lejupielādēt",
"Edit" => "Rediģēt",
"Delete" => "Dzēst",
"New calendar" => "Jauns kalendārs",
"Edit calendar" => "Rediģēt kalendāru",
"Edit event" => "Rediģēt notikumu",
"Save event" => "Saglabāt notikumu",
"Delete event" => "Dzēst notikumu",
"Eventinfo" => "Notikuma info",
"Repeating" => "Atkārtojas",
"Alarm" => "Signāls",
"Attendees" => "Apmeklētāji",
"Share" => "Dalīties",
"Title of the Event" => "Notikuma nosaukums",
"from" => "no",
"to" => "līdz",
"All Day Event" => "Visas dienas notikums",
"Advanced options" => "Paplašinātās opcijas",
"Location" => "Vieta",
"Categories (separate by comma)" => "Kategorijas (atdalīt ar komatu)",
"Edit categories" => "Rediģēt kategoriju",
"Description" => "Apraksts",
"Export event" => "Eksportēt notikumu",
"Repeat" => "Atkārtot",
"Advanced" => "Paplašināti",
"Select weekdays" => "Izvēlieties nedēļas dienas",
"Select days" => "Izvēlieties dienas",
"and the events day of year." => "un notikuma gada dienu.",
"and the events day of month." => "un notikuma mēneša dienu.",
"Select months" => "Izvēlieties mēnešus",
"Select weeks" => "Izvēlieties nedēļas",
"and the events week of year." => "un notikuma gada nedēļu.",
"Interval" => "Intervāls",
"End" => "Beigas",
"occurrences" => "notikumu skaits",
"Visibility to people shared with" => "Redzamība cilvēkiem, ar kuriem koplietots",
"create a new calendar" => "izveidot jaunu kalendāru",
"Import a calendar file" => "Importēt kalendāra datni",
"Please choose a calendar" => "Lūdzu, izvēlieties kalendāru",
"Name of new calendar" => "Jaunā kalendāra nosaukums",
"Take an available name!" => "Paņemiet pieejamu nosaukumu!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Kalendārs ar tādu nosaukumu jau eksistē. Ja tomēr turpināsiet, šie kalendāri tiks apvienoti.",
"Remove all events from the selected calendar" => "Izņemt visus notikumus no izvēlētā kalendāra",
"Import" => "Importēt",
"Close Dialog" => "Aizvērt dialoglodziņu",
"Create a new event" => "Izveidot jaunu notikumu",
"Create event" => "Izveidot notikumu",
"Share with user or group" => "Koplietot ar lietotāju vai grupu",
"Unshare" => "Pārtraukt dalīšanos",
"Not shared with anyone" => "Nav koplietošanā",
"Send Email" => "Sūtīt epastu",
"Shared via calendar" => "Koplietots caur kalendāru",
"Not shared with anyone via calendar" => "Caur kalendāru nav koplietots",
"View an event" => "Skatīt notikumu",
"Category" => "Kategorija",
"No categories selected" => "Nav izvēlētu kategoriju",
"%s of %s" => "%s no %s",
"Access Class" => "Pieejas klase",
"From" => "No",
"at" => " plkst.",
"To" => "Līdz"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);";
